package
module
Version:
v0.0.0-...-340d18e
Opens a new window with list of versions in this module.
Published: Apr 17, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Matcher[T any] interface {
PositiveMatch(value T) bool
PositiveError(value T) error
NegativeMatch(value T) bool
NegativeError(value T) error
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.